@@ -71,11 +71,17 @@ def print_key(
 
 def write_file(path, contents):
     logger.info("writing %s", path)
+    if os.path.exists(path):
+        stat = os.stat(path)
+        mode, uid, gid = stat.st_mode, stat.st_uid, stat.st_gid
+    else:
+        mode, uid, gid = 0o644, -1, -1
     d = os.path.dirname(path)
     os.path.exists(d) or os.makedirs(d)
     with tempfile.NamedTemporaryFile(dir=d, delete=False) as newfile:
         newfile.write(contents)
-        os.chmod(newfile.name, 0o644)
+        os.chmod(newfile.name, mode)
+        os.chown(newfile.name, uid, gid)
         os.rename(newfile.name, path)
 
 # return a map of filenames->filecontents
@@ -193,7 +199,7 @@ def parse_opts(argv):
     parser.add_argument('--type', default='default',
                         help='exit with error if the specified --key does not'
                              ' match type. Valid types are'
-                             ' <int|default|netaddress|dsn|raw>')
+                             ' <int|default|netaddress|dsn|swiftdevices|raw>')
     parser.add_argument('--key-default',
                         help='This option only affects running with --key.'
                              ' Print this if key is not found. This value is'
